# Copyright 2021 AI Redefined Inc. <dev+cogment@ai-r.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import glob
from typing import Any

try:
    import yaml
except ModuleNotFoundError:
    raise Exception('''
        The `cogment.generate` module requires extra dependencies,
        please install by running `pip install cogment[generate]`
    ''')


def py_path_from_proto_path(proto: str) -> str:
    return proto.split(".")[0] + "_pb2"


def py_alias_from_proto_path(proto: str) -> str:
    return proto.split(".")[0] + "_pb"


def token_as_proto_token(yaml_token: str, proto_file_content) -> str:
    token = yaml_token.split(".")[1]

    for file in proto_file_content:
        if token in proto_file_content[file]:
            return f"{py_alias_from_proto_path(file)}.{token}"

    raise Exception(f"TOKEN {token} NOT FOUND IN ANY FILE")


def proto_import_line(proto: str) -> str:
    return (
        f"import {py_path_from_proto_path(proto)} as {py_alias_from_proto_path(proto)}"
    )


def python_import_line(py_module: str) -> str:
    return f"import {py_module}"


def proto_lib_line(proto: str) -> str:
    return f'protolib = "{py_path_from_proto_path(proto)}"'


def actor_class_line(actor_class) -> str:
    actor_className = actor_class["name"]
    return f"_{actor_className}_class"


def main():

    # Closure with proto_file_content in it
    def actor_classes_block(actor_class) -> str:
        return f"""
_{actor_class['name']}_class = _cog.actor.ActorClass(
    name="{actor_class['name']}",
    config_type={token_as_proto_token(actor_class['config_type'], proto_file_content)
        if 'config_type' in actor_class else 'None'},
    action_space={token_as_proto_token(actor_class['action']['space'], proto_file_content)},
    observation_space={token_as_proto_token(actor_class['observation']['space'], proto_file_content)},
    observation_delta={token_as_proto_token(actor_class['observation']['delta'], proto_file_content)
        if 'delta' in actor_class['observation']
        else token_as_proto_token(actor_class['observation']['space'], proto_file_content)},
    observation_delta_apply_fn=_cog.delta_encoding._apply_delta_replace,
)
        """

    with open("cogment.yaml", "r") as stream:
        cog_settings = yaml.safe_load(stream)

        proto_files = cog_settings["import"]["proto"]
        proto_file_content = {}

        for file in proto_files:
            with open(file, "r") as file_data:
                proto_file_content[file] = file_data.read()

        os.system(
            "python -m grpc_tools.protoc -I . --python_out=. " + " ".join(proto_files)
        )

        line_break = "\n"  # f strings can't have backslashes in them
        comma_line_break_tab = ",\n\t"  # f strings can't have backslashes in them

        cog_settings_string = f"""
import cogment as _cog
from types import SimpleNamespace
from typing import List

{line_break.join(map(proto_import_line, cog_settings.get('import', {}).get('proto', [])))}
{line_break.join(map(python_import_line, cog_settings.get('import', {}).get('python', [])))}
{line_break.join(map(proto_lib_line, cog_settings.get('import', {}).get('proto', [])))}
{line_break.join(map(actor_classes_block, cog_settings.get('actor_classes', [])))}

actor_classes = _cog.actor.ActorClassList(
    {comma_line_break_tab.join(map(actor_class_line, cog_settings.get('actor_classes', [])))}
)

trial = SimpleNamespace(config_type={token_as_proto_token(cog_settings['trial']['config_type'], proto_file_content)
    if 'trial' in cog_settings and 'config_type' in cog_settings['trial']
    else 'None'})

# Environment
environment = SimpleNamespace(config_type={
    token_as_proto_token(cog_settings['environment']['config_type'], proto_file_content)
    if 'environment' in cog_settings and 'config_type' in cog_settings['environment']
    else 'None'})
        """
        with open("cog_settings.py", "w") as text_file:
            text_file.write(cog_settings_string)


if __name__ == "__main__":
    main()



# Copyright 2021 AI Redefined Inc. <dev+cogment@ai-r.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
from collections import deque
from typing import List, Any

import cogment.api.common_pb2 as common_api
from cogment.environment import ENVIRONMENT_ACTOR_NAME
from cogment.errors import Error


class Trial:
    class MinimalComponent:
        def __init__(self, name):
            self.name = name
            self._messages = deque()

        def add_prepared_message(self, payload):
            self._messages.append(payload)

        def get_prepared_messages(self):
            while len(self._messages) > 0:
                payload = self._messages.popleft()
                # sender_name is not needed for sending messages
                message = common_api.Message(tick_id=-1, receiver_name=self.name)
                if payload is not None:
                    message.payload.Pack(payload)
                yield message

    class Component(MinimalComponent):
        def __init__(self, name, actor_class):
            super().__init__(name)
            self.actor_class = actor_class
            self._reward_data = deque()

        def add_prepared_reward_data(self, tick_id, value, confidence, user_data):
            self._reward_data.append((tick_id, value, confidence, user_data))

        def get_prepared_rewards(self):
            while len(self._reward_data) > 0:
                (tick_id, reward_value, confidence, user_data) = self._reward_data.popleft()
                source = common_api.RewardSource(
                    # sender_name is not needed for sending rewards
                    value=reward_value,
                    confidence=confidence
                )
                if user_data is not None:
                    source.user_data.Pack(user_data)

                reward = common_api.Reward(
                    value=reward_value,  # This will be overwritten by orchestrator before delivery
                    receiver_name=self.name,
                    tick_id=tick_id,
                )
                reward.sources.append(source)
                yield reward

    def __init__(self, id, actors_in_trial, cog_settings):
        self.id = id
        self.over = False
        self.cog_settings = cog_settings
        self.tick_id = -1
        self.environment = self.MinimalComponent(ENVIRONMENT_ACTOR_NAME)

        self.__actor_by_name = {}

        self.actors = []
        self.actor_counts = []
        self._add_actors(actors_in_trial)
        self._add_actor_counts()

    def _add_actors(self, actors_in_trial):
        for actor_in_trial in actors_in_trial:
            if actor_in_trial.actor_class not in self.cog_settings.actor_classes:
                raise Error(f"class '{actor_in_trial.actor_class}' of actor '{actor_in_trial.name}' can not be found.")
            actor_class = self.cog_settings.actor_classes[actor_in_trial.actor_class]
            actor = self.Component(name=actor_in_trial.name, actor_class=actor_class)
            self.actors.append(actor)

    def _add_actor_counts(self):
        class_list = self.cog_settings.actor_classes._actor_classes_list
        self.actor_counts = [0] * len(class_list)
        for class_index, class_member in enumerate(class_list):
            for actor in self.actors:
                if class_member.name == actor.actor_class.name:
                    self.actor_counts[class_index] += 1

    def get_actors(self, pattern_list: List[str]):
        if not isinstance(pattern_list, list):
            raise TypeError(f"The pattern_list must be a list: {type(pattern_list)}")

        matched_indexes = set()
        for pattern in pattern_list:
            if not isinstance(pattern, str):
                raise TypeError(f"The pattern must be a string: {type(pattern)}")

            elif pattern == "*":
                if len(pattern_list) > 1:
                    logging.warning("Redundant actors in pattern_list since the wildcard (*) is used")
                return self.actors

            elif "." not in pattern:
                match = None
                for index, actor in enumerate(self.actors):
                    if actor.name == pattern:
                        match = index
                        break
                if match is not None:
                    matched_indexes.add(match)
                else:
                    logging.warning(f"Unknown actor name in pattern_list [{pattern}]")

            else:
                [class_name, actor_name] = pattern.split(".")

                if actor_name == "*":
                    matches = set()
                    for index, actor in enumerate(self.actors):
                        if actor.actor_class.name == class_name:
                            matches.add(index)
                    if matches:
                        matched_indexes |= matches
                    else:
                        logging.warning(f"Unknown actor class in pattern_list [{class_name}]")
                else:
                    match = None
                    for index, actor in enumerate(self.actors):
                        if actor.name == actor_name and actor.actor_class.name == class_name:
                            match = index
                            break
                    if match is not None:
                        matched_indexes.add(match)
                    else:
                        logging.warning(f"Unknown actor and class in pattern_list [{pattern}]")

        return [self.actors[i] for i in matched_indexes]

    def add_reward(self, value, confidence, to, tick_id, user_data):
        for dest_actor in self.get_actors(pattern_list=to):
            dest_actor.add_prepared_reward_data(
                tick_id=tick_id,
                value=value,
                confidence=confidence,
                user_data=user_data
            )

    def _gather_all_rewards(self):
        for dest_actor in self.actors:
            for reward in dest_actor.get_prepared_rewards():
                yield reward

    # We default `to` so users can provide a `to_environment=True` without a `to` parameter
    def send_message(self, payload, to=[], to_environment=False):
        if to_environment:
            self.environment.add_prepared_message(payload=payload)
        for actor in self.get_actors(pattern_list=to):
            actor.add_prepared_message(payload=payload)

    def _gather_all_messages(self):
        for dest_actor in self.actors:
            for message in dest_actor.get_prepared_messages():
                yield message

        for message in self.environment.get_prepared_messages():
            yield message



# Copyright 2021 AI Redefined Inc. <dev+cogment@ai-r.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
from typing import Callable, Awaitable, Dict, List, Any
from types import ModuleType
import os
import asyncio
from types import SimpleNamespace
import grpc
import grpc.aio  # type: ignore
from prometheus_client import start_http_server, CollectorRegistry
from prometheus_client.core import REGISTRY  # type: ignore

from cogment.actor import ActorSession, ActorClass
from cogment.environment import EnvironmentSession
from cogment.prehook import PrehookSession
from cogment.datalog import DatalogSession
from cogment.control import Controller

# Controller
import cogment.api.orchestrator_pb2_grpc as grpc_api

# Agent
from cogment.agent_service import AgentServicer
from cogment.api.agent_pb2 import _AGENTENDPOINT as agent_endpoint_descriptor
from cogment.api.agent_pb2_grpc import add_AgentEndpointServicer_to_server

# Client
from cogment.client_service import ClientServicer

# Environment
from cogment.env_service import EnvironmentServicer
from cogment.api.environment_pb2_grpc import add_EnvironmentEndpointServicer_to_server

# Prehook
from cogment.hooks_service import PrehookServicer
from cogment.api.hooks_pb2_grpc import add_TrialHooksServicer_to_server

# Log Exporter
from cogment.log_exporter_service import LogExporterService
from cogment.api.datalog_pb2_grpc import add_LogExporterServicer_to_server


DEFAULT_MAX_WORKERS = 1
ENABLE_REFLECTION_VAR_NAME = "COGMENT_GRPC_REFLECTION"
DEFAULT_ENABLE_REFLECTION = os.getenv(ENABLE_REFLECTION_VAR_NAME, "false")
DEFAULT_PROMETHEUS_PORT = 8000


def _add_actor_service(grpc_server, impls, service_names, cog_settings, prometheus_registry):
    servicer = AgentServicer(impls, cog_settings, prometheus_registry)
    add_AgentEndpointServicer_to_server(servicer, grpc_server)
    service_names.append(agent_endpoint_descriptor.full_name)


def _add_env_service(grpc_server, impls, cog_settings, prometheus_registry):
    servicer = EnvironmentServicer(impls, cog_settings, prometheus_registry)
    add_EnvironmentEndpointServicer_to_server(servicer, grpc_server)


def _add_prehook_service(grpc_server, impls, cog_settings, prometheus_registry):
    servicer = PrehookServicer(impls, cog_settings, prometheus_registry)
    add_TrialHooksServicer_to_server(servicer, grpc_server)


def _add_datalog_service(grpc_server, impl, cog_settings):
    servicer = LogExporterService(impl, cog_settings)
    add_LogExporterServicer_to_server(servicer, grpc_server)


class Endpoint:

    def __init__(self, url: str):
        self.url = url
        self.private_key = None
        self.root_certificates = None
        self.certificate_chain = None

    def set_from_files(self, private_key_file=None, root_certificates_file=None, certificate_chain_file=None):
        try:
            if private_key_file:
                with open(private_key_file) as fl:
                    self.private_key = fl.read()
                if not self.private_key:
                    self.private_key = None

            if root_certificates_file:
                with open(root_certificates_file) as fl:
                    self.root_certificates = fl.read()
                if not self.root_certificates:
                    self.root_certificates = None

            if certificate_chain_file:
                with open(certificate_chain_file) as fl:
                    self.certificate_chain = fl.read()
                if not self.certificate_chain:
                    self.certificate_chain = None

        except Exception:
            logging.error(f"Failed loading file from CWD: {os.getcwd()}")
            raise

    def __str__(self):
        result = f"Endpoint: url = {self.url}, private_key = {self.private_key}"
        result += f", root_certificates = {self.root_certificates}, certificate_chain = {self.certificate_chain}"
        return result


class ServedEndpoint:

    def __init__(self, port: int):
        self.port = port
        self.private_key_certificate_chain_pairs = None
        self.root_certificates = None

    # def set_from_files(private_key_certificate_chain_pairs_file=None, root_certificates_file=None):
    # TODO: This function would need to parse the PEM encoded `private_key_certificate_chain_pairs_file`
    #       to create the list of tuples required (see simpler version in `Endpoint` class above).

    def __str__(self):
        result = f"ServedEndpoint: port = {self.port}"
        result += f", private_key_certificate_chain_pairs = {self.private_key_certificate_chain_pairs}"
        result += f", root_certificates = {self.root_certificates}"
        return result


class Context:
    def __init__(self, user_id: str, cog_settings: ModuleType, asyncio_loop=None, prometheus_registry=REGISTRY):
        self._user_id = user_id
        self.__actor_impls: Dict[str, SimpleNamespace] = {}
        self.__env_impls: Dict[str, SimpleNamespace] = {}
        self.__prehook_impls: List[Callable[[PrehookSession], Awaitable[None]]] = []
        self.__datalog_impl: Callable[[DatalogSession], Awaitable[None]] = None
        self._grpc_server = None  # type: Any
        self._prometheus_registry = prometheus_registry
        self.__cog_settings = cog_settings

        if asyncio_loop is None:
            # Make sure we are running in a asyncio.Task.  Even if technically this init does not need
            # to be in a Task, the whole of the SDK expects to be running in Tasks of the same event loop.
            try:
                self.asyncio_loop = asyncio.get_running_loop()
            except RuntimeError:
                pass
            if self.asyncio_loop is None:
                raise RuntimeError("The Cogment SDK requires running in a Python.asyncio Task")
        else:
            self.asyncio_loop = asyncio_loop

    def register_actor(self,
                       impl: Callable[[ActorSession], Awaitable[None]],
                       impl_name: str,
                       actor_classes: List[str] = []):
        if self._grpc_server is not None:
            raise RuntimeError("Cannot register an actor after the server is started")
        if impl_name in self.__actor_impls:
            raise RuntimeError(f"The actor implementation name must be unique: [{impl_name}]")

        self.__actor_impls[impl_name] = SimpleNamespace(impl=impl, actor_classes=actor_classes)

    def register_environment(self,
                             impl: Callable[[EnvironmentSession], Awaitable[None]],
                             impl_name: str = "default"):
        if self._grpc_server is not None:
            raise RuntimeError("Cannot register an environment after the server is started")
        if impl_name in self.__env_impls:
            raise RuntimeError(f"The environment implementation name must be unique: [{impl_name}]")

        self.__env_impls[impl_name] = SimpleNamespace(impl=impl)

    def register_pre_trial_hook(self,
                                impl: Callable[[PrehookSession], Awaitable[None]]):
        if self._grpc_server is not None:
            raise RuntimeError("Cannot register a pre-trial hook after the server is started")

        self.__prehook_impls.append(impl)

    def register_datalog(self,
                         impl: Callable[[DatalogSession], Awaitable[None]]):
        if self._grpc_server is not None:
            raise RuntimeError("Cannot register a datalog after the server is started")
        if self.__datalog_impl is not None:
            raise RuntimeError("Only one datalog service can be registered")

        self.__datalog_impl = impl

    async def serve_all_registered(self, served_endpoint: ServedEndpoint,
                                   prometheus_port=DEFAULT_PROMETHEUS_PORT):
        if (len(self.__actor_impls) == 0 and
                len(self.__env_impls) == 0 and
                len(self.__prehook_impls) == 0 and
                self.__datalog_impl is None):
            raise RuntimeError("Nothing registered to serve!")
        if self._grpc_server is not None:
            raise RuntimeError("Cannot serve the same components twice")

        self._grpc_server = grpc.aio.server()

        service_names: List[str] = []
        if self.__actor_impls:
            _add_actor_service(
                self._grpc_server,
                self.__actor_impls,
                service_names,
                self.__cog_settings,
                self._prometheus_registry
            )

        if self.__env_impls:
            _add_env_service(
                self._grpc_server,
                self.__env_impls,
                self.__cog_settings,
                self._prometheus_registry
            )

        if self.__prehook_impls:
            _add_prehook_service(
                self._grpc_server,
                self.__prehook_impls,
                self.__cog_settings,
                self._prometheus_registry
            )

        if self.__datalog_impl is not None:
            _add_datalog_service(
                self._grpc_server,
                self.__datalog_impl,
                self.__cog_settings
            )

        if self._prometheus_registry is not None and prometheus_port is not None:
            start_http_server(prometheus_port, "", self._prometheus_registry)

        address = f"[::]:{served_endpoint.port}"
        if served_endpoint.private_key_certificate_chain_pairs is None:
            self._grpc_server.add_insecure_port(address)
        else:
            if served_endpoint.root_certificates:
                require_client_auth = True
                root = bytes(served_endpoint.root_certificates, "utf-8")
            else:
                require_client_auth = False
                root = None
            certs = []
            for (key, chain) in served_endpoint.private_key_certificate_chain_pairs:
                certs.append((bytes(key, "utf-8"), bytes(chain, "utf-8")))
            if not certs:
                certs = None

            creds = grpc.ssl_server_credentials(certs, root, require_client_auth)
            self._grpc_server.add_secure_port(address, creds)

        await self._grpc_server.start()
        await self._grpc_server.wait_for_termination()
        logging.debug(f"Context gRPC server at port [{served_endpoint.port}] for user [{self._user_id}] exited")

    def _get_control_stub(self, endpoint):
        if endpoint.private_key is None:
            channel = grpc.aio.insecure_channel(endpoint.url)
        else:
            if endpoint.root_certificates:
                root = bytes(endpoint.root_certificates, "utf-8")
            else:
                root = None
            if endpoint.private_key:
                key = bytes(endpoint.private_key, "utf-8")
            else:
                key = None
            if endpoint.certificate_chain:
                certs = bytes(endpoint.certificate_chain, "utf-8")
            else:
                certs = None
            creds = grpc.ssl_channel_credentials(root, key, certs)
            channel = grpc.aio.secure_channel(endpoint.url, creds)

        return grpc_api.TrialLifecycleStub(channel)

    def get_controller(self, endpoint: Endpoint):
        stub = self._get_control_stub(endpoint)
        return Controller(stub, self._user_id)

    async def join_trial(self, trial_id, endpoint: Endpoint, impl_name, actor_name=None):
        actor_impl = self.__actor_impls.get(impl_name)
        if actor_impl is None:
            raise Exception(f"Unknown actor impl [{impl_name}].  Was it registered?")

        servicer = ClientServicer(self.__cog_settings, endpoint)
        await servicer.run(trial_id, actor_impl.impl, impl_name, actor_impl.actor_classes, actor_name)

    def __str__(self):
        result = f"Context:"
        return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/discovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/discovery.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x63ogment/api/discovery.proto\x12\x07\x63ogment\x1a\x18\x63ogment/api/common.proto\"g\n\x0fRegisterRequest\x12*\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x18.cogment.ServiceEndpoint\x12(\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x17.cogment.ServiceDetails\"\x9b\x01\n\rRegisterReply\x12-\n\x06status\x18\x01 \x01(\x0e\x32\x1d.cogment.RegisterReply.Status\x12\x11\n\terror_msg\x18\x02 \x01(\t\x12\x12\n\nservice_id\x18\x03 \x01(\x04\x12\x0e\n\x06secret\x18\x04 \x01(\t\"$\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x12\n\x0eINTERNAL_ERROR\x10\x01\"7\n\x11\x44\x65registerRequest\x12\x12\n\nservice_id\x18\x01 \x01(\x04\x12\x0e\n\x06secret\x18\x02 \x01(\t\"{\n\x0f\x44\x65registerReply\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.cogment.DeregisterReply.Status\x12\x11\n\terror_msg\x18\x02 \x01(\t\"$\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x12\n\x0eINTERNAL_ERROR\x10\x01\"]\n\x0eInquireRequest\x12\x14\n\nservice_id\x18\x01 \x01(\x04H\x00\x12*\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x17.cogment.ServiceDetailsH\x00\x42\t\n\x07inquiry\"6\n\x0cInquireReply\x12&\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x18.cogment.FullServiceData\"\x8a\x01\n\x0fServiceEndpoint\x12\x33\n\x08protocol\x18\x01 \x01(\x0e\x32!.cogment.ServiceEndpoint.Protocol\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\"\"\n\x08Protocol\x12\x08\n\x04GRPC\x10\x00\x12\x0c\n\x08GRPC_SSL\x10\x01\"\xa4\x01\n\x0eServiceDetails\x12\"\n\x04type\x18\x01 \x01(\x0e\x32\x14.cogment.ServiceType\x12;\n\nproperties\x18\x02 \x03(\x0b\x32\'.cogment.ServiceDetails.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x0f\x46ullServiceData\x12*\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x18.cogment.ServiceEndpoint\x12\x12\n\nservice_id\x18\x02 \x01(\x04\x12(\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x17.cogment.ServiceDetails*\xbc\x01\n\x0bServiceType\x12\x13\n\x0fUNKNOWN_SERVICE\x10\x00\x12\x1c\n\x18TRIAL_LIFE_CYCLE_SERVICE\x10\x01\x12#\n\x1f\x43LIENT_ACTOR_CONNECTION_SERVICE\x10\x02\x12\x11\n\rACTOR_SERVICE\x10\x03\x12\x17\n\x13\x45NVIRONMENT_SERVICE\x10\x04\x12\x14\n\x10PRE_HOOK_SERVICE\x10\x05\x12\x13\n\x0f\x44\x41TALOG_SERVICE\x10\x06\x32\x94\x02\n\tDiscovery\x12\x42\n\x08Register\x12\x18.cogment.RegisterRequest\x1a\x16.cogment.RegisterReply\"\x00(\x01\x30\x01\x12H\n\nDeregister\x12\x1a.cogment.DeregisterRequest\x1a\x18.cogment.DeregisterReply\"\x00(\x01\x30\x01\x12=\n\x07Inquire\x12\x17.cogment.InquireRequest\x1a\x15.cogment.InquireReply\"\x00\x30\x01\x12:\n\x07Version\x12\x17.cogment.VersionRequest\x1a\x14.cogment.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])

_SERVICETYPE = _descriptor.EnumDescriptor(
  name='ServiceType',
  full_name='cogment.ServiceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SERVICE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRIAL_LIFE_CYCLE_SERVICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_ACTOR_CONNECTION_SERVICE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_SERVICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENT_SERVICE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRE_HOOK_SERVICE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATALOG_SERVICE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1096,
  serialized_end=1284,
)
_sym_db.RegisterEnumDescriptor(_SERVICETYPE)

ServiceType = enum_type_wrapper.EnumTypeWrapper(_SERVICETYPE)
UNKNOWN_SERVICE = 0
TRIAL_LIFE_CYCLE_SERVICE = 1
CLIENT_ACTOR_CONNECTION_SERVICE = 2
ACTOR_SERVICE = 3
ENVIRONMENT_SERVICE = 4
PRE_HOOK_SERVICE = 5
DATALOG_SERVICE = 6


_REGISTERREPLY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='cogment.RegisterReply.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=291,
  serialized_end=327,
)
_sym_db.RegisterEnumDescriptor(_REGISTERREPLY_STATUS)

_DEREGISTERREPLY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='cogment.DeregisterReply.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=291,
  serialized_end=327,
)
_sym_db.RegisterEnumDescriptor(_DEREGISTERREPLY_STATUS)

_SERVICEENDPOINT_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='cogment.ServiceEndpoint.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRPC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRPC_SSL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=767,
  serialized_end=801,
)
_sym_db.RegisterEnumDescriptor(_SERVICEENDPOINT_PROTOCOL)


_REGISTERREQUEST = _descriptor.Descriptor(
  name='RegisterRequest',
  full_name='cogment.RegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogment.RegisterRequest.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='cogment.RegisterRequest.details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=169,
)


_REGISTERREPLY = _descriptor.Descriptor(
  name='RegisterReply',
  full_name='cogment.RegisterReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='cogment.RegisterReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='cogment.RegisterReply.error_msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='cogment.RegisterReply.service_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='cogment.RegisterReply.secret', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REGISTERREPLY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=327,
)


_DEREGISTERREQUEST = _descriptor.Descriptor(
  name='DeregisterRequest',
  full_name='cogment.DeregisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_id', full_name='cogment.DeregisterRequest.service_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='cogment.DeregisterRequest.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=384,
)


_DEREGISTERREPLY = _descriptor.Descriptor(
  name='DeregisterReply',
  full_name='cogment.DeregisterReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='cogment.DeregisterReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='cogment.DeregisterReply.error_msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEREGISTERREPLY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=509,
)


_INQUIREREQUEST = _descriptor.Descriptor(
  name='InquireRequest',
  full_name='cogment.InquireRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_id', full_name='cogment.InquireRequest.service_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='cogment.InquireRequest.details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='inquiry', full_name='cogment.InquireRequest.inquiry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=511,
  serialized_end=604,
)


_INQUIREREPLY = _descriptor.Descriptor(
  name='InquireReply',
  full_name='cogment.InquireReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='cogment.InquireReply.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=660,
)


_SERVICEENDPOINT = _descriptor.Descriptor(
  name='ServiceEndpoint',
  full_name='cogment.ServiceEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='cogment.ServiceEndpoint.protocol', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='cogment.ServiceEndpoint.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='cogment.ServiceEndpoint.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SERVICEENDPOINT_PROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=801,
)


_SERVICEDETAILS_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='cogment.ServiceDetails.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cogment.ServiceDetails.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.ServiceDetails.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=919,
  serialized_end=968,
)

_SERVICEDETAILS = _descriptor.Descriptor(
  name='ServiceDetails',
  full_name='cogment.ServiceDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='cogment.ServiceDetails.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='cogment.ServiceDetails.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SERVICEDETAILS_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=804,
  serialized_end=968,
)


_FULLSERVICEDATA = _descriptor.Descriptor(
  name='FullServiceData',
  full_name='cogment.FullServiceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogment.FullServiceData.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='cogment.FullServiceData.service_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='cogment.FullServiceData.details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1093,
)

_REGISTERREQUEST.fields_by_name['endpoint'].message_type = _SERVICEENDPOINT
_REGISTERREQUEST.fields_by_name['details'].message_type = _SERVICEDETAILS
_REGISTERREPLY.fields_by_name['status'].enum_type = _REGISTERREPLY_STATUS
_REGISTERREPLY_STATUS.containing_type = _REGISTERREPLY
_DEREGISTERREPLY.fields_by_name['status'].enum_type = _DEREGISTERREPLY_STATUS
_DEREGISTERREPLY_STATUS.containing_type = _DEREGISTERREPLY
_INQUIREREQUEST.fields_by_name['details'].message_type = _SERVICEDETAILS
_INQUIREREQUEST.oneofs_by_name['inquiry'].fields.append(
  _INQUIREREQUEST.fields_by_name['service_id'])
_INQUIREREQUEST.fields_by_name['service_id'].containing_oneof = _INQUIREREQUEST.oneofs_by_name['inquiry']
_INQUIREREQUEST.oneofs_by_name['inquiry'].fields.append(
  _INQUIREREQUEST.fields_by_name['details'])
_INQUIREREQUEST.fields_by_name['details'].containing_oneof = _INQUIREREQUEST.oneofs_by_name['inquiry']
_INQUIREREPLY.fields_by_name['data'].message_type = _FULLSERVICEDATA
_SERVICEENDPOINT.fields_by_name['protocol'].enum_type = _SERVICEENDPOINT_PROTOCOL
_SERVICEENDPOINT_PROTOCOL.containing_type = _SERVICEENDPOINT
_SERVICEDETAILS_PROPERTIESENTRY.containing_type = _SERVICEDETAILS
_SERVICEDETAILS.fields_by_name['type'].enum_type = _SERVICETYPE
_SERVICEDETAILS.fields_by_name['properties'].message_type = _SERVICEDETAILS_PROPERTIESENTRY
_FULLSERVICEDATA.fields_by_name['endpoint'].message_type = _SERVICEENDPOINT
_FULLSERVICEDATA.fields_by_name['details'].message_type = _SERVICEDETAILS
DESCRIPTOR.message_types_by_name['RegisterRequest'] = _REGISTERREQUEST
DESCRIPTOR.message_types_by_name['RegisterReply'] = _REGISTERREPLY
DESCRIPTOR.message_types_by_name['DeregisterRequest'] = _DEREGISTERREQUEST
DESCRIPTOR.message_types_by_name['DeregisterReply'] = _DEREGISTERREPLY
DESCRIPTOR.message_types_by_name['InquireRequest'] = _INQUIREREQUEST
DESCRIPTOR.message_types_by_name['InquireReply'] = _INQUIREREPLY
DESCRIPTOR.message_types_by_name['ServiceEndpoint'] = _SERVICEENDPOINT
DESCRIPTOR.message_types_by_name['ServiceDetails'] = _SERVICEDETAILS
DESCRIPTOR.message_types_by_name['FullServiceData'] = _FULLSERVICEDATA
DESCRIPTOR.enum_types_by_name['ServiceType'] = _SERVICETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RegisterRequest = _reflection.GeneratedProtocolMessageType('RegisterRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERREQUEST,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RegisterRequest)
  })
_sym_db.RegisterMessage(RegisterRequest)

RegisterReply = _reflection.GeneratedProtocolMessageType('RegisterReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERREPLY,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RegisterReply)
  })
_sym_db.RegisterMessage(RegisterReply)

DeregisterRequest = _reflection.GeneratedProtocolMessageType('DeregisterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEREGISTERREQUEST,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.DeregisterRequest)
  })
_sym_db.RegisterMessage(DeregisterRequest)

DeregisterReply = _reflection.GeneratedProtocolMessageType('DeregisterReply', (_message.Message,), {
  'DESCRIPTOR' : _DEREGISTERREPLY,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.DeregisterReply)
  })
_sym_db.RegisterMessage(DeregisterReply)

InquireRequest = _reflection.GeneratedProtocolMessageType('InquireRequest', (_message.Message,), {
  'DESCRIPTOR' : _INQUIREREQUEST,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.InquireRequest)
  })
_sym_db.RegisterMessage(InquireRequest)

InquireReply = _reflection.GeneratedProtocolMessageType('InquireReply', (_message.Message,), {
  'DESCRIPTOR' : _INQUIREREPLY,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.InquireReply)
  })
_sym_db.RegisterMessage(InquireReply)

ServiceEndpoint = _reflection.GeneratedProtocolMessageType('ServiceEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEENDPOINT,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ServiceEndpoint)
  })
_sym_db.RegisterMessage(ServiceEndpoint)

ServiceDetails = _reflection.GeneratedProtocolMessageType('ServiceDetails', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERVICEDETAILS_PROPERTIESENTRY,
    '__module__' : 'cogment.api.discovery_pb2'
    # @@protoc_insertion_point(class_scope:cogment.ServiceDetails.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _SERVICEDETAILS,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ServiceDetails)
  })
_sym_db.RegisterMessage(ServiceDetails)
_sym_db.RegisterMessage(ServiceDetails.PropertiesEntry)

FullServiceData = _reflection.GeneratedProtocolMessageType('FullServiceData', (_message.Message,), {
  'DESCRIPTOR' : _FULLSERVICEDATA,
  '__module__' : 'cogment.api.discovery_pb2'
  # @@protoc_insertion_point(class_scope:cogment.FullServiceData)
  })
_sym_db.RegisterMessage(FullServiceData)


_SERVICEDETAILS_PROPERTIESENTRY._options = None

_DISCOVERY = _descriptor.ServiceDescriptor(
  name='Discovery',
  full_name='cogment.Discovery',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1287,
  serialized_end=1563,
  methods=[
  _descriptor.MethodDescriptor(
    name='Register',
    full_name='cogment.Discovery.Register',
    index=0,
    containing_service=None,
    input_type=_REGISTERREQUEST,
    output_type=_REGISTERREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Deregister',
    full_name='cogment.Discovery.Deregister',
    index=1,
    containing_service=None,
    input_type=_DEREGISTERREQUEST,
    output_type=_DEREGISTERREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Inquire',
    full_name='cogment.Discovery.Inquire',
    index=2,
    containing_service=None,
    input_type=_INQUIREREQUEST,
    output_type=_INQUIREREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogment.Discovery.Version',
    index=3,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DISCOVERY)

DESCRIPTOR.services_by_name['Discovery'] = _DISCOVERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/model_registry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/model_registry.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cogment/api/model_registry.proto\x12\x07\x63ogment\"\x83\x01\n\tModelInfo\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x33\n\tuser_data\x18\x02 \x03(\x0b\x32 .cogment.ModelInfo.UserDataEntry\x1a/\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfd\x01\n\x10ModelVersionInfo\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0eversion_number\x18\x02 \x01(\r\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\x06\x12\x10\n\x08\x61rchived\x18\x04 \x01(\x08\x12\x11\n\tdata_hash\x18\x05 \x01(\t\x12\x11\n\tdata_size\x18\x06 \x01(\x06\x12:\n\tuser_data\x18\x07 \x03(\x0b\x32\'.cogment.ModelVersionInfo.UserDataEntry\x1a/\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\x1a\x43reateOrUpdateModelRequest\x12&\n\nmodel_info\x18\x01 \x01(\x0b\x32\x12.cogment.ModelInfo\"\x1a\n\x18\x43reateOrUpdateModelReply\"V\n\x15RetrieveModelsRequest\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x14\n\x0cmodels_count\x18\x03 \x01(\r\x12\x14\n\x0cmodel_handle\x18\x04 \x01(\t\"Y\n\x13RetrieveModelsReply\x12\'\n\x0bmodel_infos\x18\x01 \x03(\x0b\x32\x12.cogment.ModelInfo\x12\x19\n\x11next_model_handle\x18\x02 \x01(\t\"&\n\x12\x44\x65leteModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65leteModelReply\"\xef\x01\n\x19\x43reateVersionRequestChunk\x12;\n\x06header\x18\x01 \x01(\x0b\x32).cogment.CreateVersionRequestChunk.HeaderH\x00\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.cogment.CreateVersionRequestChunk.BodyH\x00\x1a\x39\n\x06Header\x12/\n\x0cversion_info\x18\x01 \x01(\x0b\x32\x19.cogment.ModelVersionInfo\x1a\x1a\n\x04\x42ody\x12\x12\n\ndata_chunk\x18\x01 \x01(\x0c\x42\x05\n\x03msg\"E\n\x12\x43reateVersionReply\x12/\n\x0cversion_info\x18\x01 \x01(\x0b\x32\x19.cogment.ModelVersionInfo\"x\n\x1bRetrieveVersionInfosRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x17\n\x0fversion_numbers\x18\x02 \x03(\x05\x12\x16\n\x0eversions_count\x18\x03 \x01(\r\x12\x16\n\x0eversion_handle\x18\x04 \x01(\t\"j\n\x19RetrieveVersionInfosReply\x12\x30\n\rversion_infos\x18\x01 \x03(\x0b\x32\x19.cogment.ModelVersionInfo\x12\x1b\n\x13next_version_handle\x18\x02 \x01(\t\"F\n\x1aRetrieveVersionDataRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0eversion_number\x18\x02 \x01(\x05\"3\n\x1dRetrieveVersionDataReplyChunk\x12\x12\n\ndata_chunk\x18\x01 \x01(\x0c\x32\xaf\x04\n\x0fModelRegistrySP\x12_\n\x13\x43reateOrUpdateModel\x12#.cogment.CreateOrUpdateModelRequest\x1a!.cogment.CreateOrUpdateModelReply\"\x00\x12G\n\x0b\x44\x65leteModel\x12\x1b.cogment.DeleteModelRequest\x1a\x19.cogment.DeleteModelReply\"\x00\x12P\n\x0eRetrieveModels\x12\x1e.cogment.RetrieveModelsRequest\x1a\x1c.cogment.RetrieveModelsReply\"\x00\x12T\n\rCreateVersion\x12\".cogment.CreateVersionRequestChunk\x1a\x1b.cogment.CreateVersionReply\"\x00(\x01\x12\x62\n\x14RetrieveVersionInfos\x12$.cogment.RetrieveVersionInfosRequest\x1a\".cogment.RetrieveVersionInfosReply\"\x00\x12\x66\n\x13RetrieveVersionData\x12#.cogment.RetrieveVersionDataRequest\x1a&.cogment.RetrieveVersionDataReplyChunk\"\x00\x30\x01\x62\x06proto3'
)




_MODELINFO_USERDATAENTRY = _descriptor.Descriptor(
  name='UserDataEntry',
  full_name='cogment.ModelInfo.UserDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cogment.ModelInfo.UserDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.ModelInfo.UserDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=177,
)

_MODELINFO = _descriptor.Descriptor(
  name='ModelInfo',
  full_name='cogment.ModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.ModelInfo.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogment.ModelInfo.user_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MODELINFO_USERDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=177,
)


_MODELVERSIONINFO_USERDATAENTRY = _descriptor.Descriptor(
  name='UserDataEntry',
  full_name='cogment.ModelVersionInfo.UserDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cogment.ModelVersionInfo.UserDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.ModelVersionInfo.UserDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=177,
)

_MODELVERSIONINFO = _descriptor.Descriptor(
  name='ModelVersionInfo',
  full_name='cogment.ModelVersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.ModelVersionInfo.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_number', full_name='cogment.ModelVersionInfo.version_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='cogment.ModelVersionInfo.creation_timestamp', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archived', full_name='cogment.ModelVersionInfo.archived', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='cogment.ModelVersionInfo.data_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_size', full_name='cogment.ModelVersionInfo.data_size', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogment.ModelVersionInfo.user_data', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MODELVERSIONINFO_USERDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=433,
)


_CREATEORUPDATEMODELREQUEST = _descriptor.Descriptor(
  name='CreateOrUpdateModelRequest',
  full_name='cogment.CreateOrUpdateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_info', full_name='cogment.CreateOrUpdateModelRequest.model_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=503,
)


_CREATEORUPDATEMODELREPLY = _descriptor.Descriptor(
  name='CreateOrUpdateModelReply',
  full_name='cogment.CreateOrUpdateModelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=531,
)


_RETRIEVEMODELSREQUEST = _descriptor.Descriptor(
  name='RetrieveModelsRequest',
  full_name='cogment.RetrieveModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_ids', full_name='cogment.RetrieveModelsRequest.model_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models_count', full_name='cogment.RetrieveModelsRequest.models_count', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_handle', full_name='cogment.RetrieveModelsRequest.model_handle', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=619,
)


_RETRIEVEMODELSREPLY = _descriptor.Descriptor(
  name='RetrieveModelsReply',
  full_name='cogment.RetrieveModelsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_infos', full_name='cogment.RetrieveModelsReply.model_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_model_handle', full_name='cogment.RetrieveModelsReply.next_model_handle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=710,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='cogment.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.DeleteModelRequest.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=750,
)


_DELETEMODELREPLY = _descriptor.Descriptor(
  name='DeleteModelReply',
  full_name='cogment.DeleteModelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=770,
)


_CREATEVERSIONREQUESTCHUNK_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='cogment.CreateVersionRequestChunk.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='cogment.CreateVersionRequestChunk.Header.version_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=920,
  serialized_end=977,
)

_CREATEVERSIONREQUESTCHUNK_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='cogment.CreateVersionRequestChunk.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_chunk', full_name='cogment.CreateVersionRequestChunk.Body.data_chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1005,
)

_CREATEVERSIONREQUESTCHUNK = _descriptor.Descriptor(
  name='CreateVersionRequestChunk',
  full_name='cogment.CreateVersionRequestChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='cogment.CreateVersionRequestChunk.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='cogment.CreateVersionRequestChunk.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEVERSIONREQUESTCHUNK_HEADER, _CREATEVERSIONREQUESTCHUNK_BODY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='msg', full_name='cogment.CreateVersionRequestChunk.msg',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=773,
  serialized_end=1012,
)


_CREATEVERSIONREPLY = _descriptor.Descriptor(
  name='CreateVersionReply',
  full_name='cogment.CreateVersionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='cogment.CreateVersionReply.version_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1083,
)


_RETRIEVEVERSIONINFOSREQUEST = _descriptor.Descriptor(
  name='RetrieveVersionInfosRequest',
  full_name='cogment.RetrieveVersionInfosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.RetrieveVersionInfosRequest.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_numbers', full_name='cogment.RetrieveVersionInfosRequest.version_numbers', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions_count', full_name='cogment.RetrieveVersionInfosRequest.versions_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_handle', full_name='cogment.RetrieveVersionInfosRequest.version_handle', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1205,
)


_RETRIEVEVERSIONINFOSREPLY = _descriptor.Descriptor(
  name='RetrieveVersionInfosReply',
  full_name='cogment.RetrieveVersionInfosReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_infos', full_name='cogment.RetrieveVersionInfosReply.version_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_version_handle', full_name='cogment.RetrieveVersionInfosReply.next_version_handle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1313,
)


_RETRIEVEVERSIONDATAREQUEST = _descriptor.Descriptor(
  name='RetrieveVersionDataRequest',
  full_name='cogment.RetrieveVersionDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_id', full_name='cogment.RetrieveVersionDataRequest.model_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_number', full_name='cogment.RetrieveVersionDataRequest.version_number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1385,
)


_RETRIEVEVERSIONDATAREPLYCHUNK = _descriptor.Descriptor(
  name='RetrieveVersionDataReplyChunk',
  full_name='cogment.RetrieveVersionDataReplyChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_chunk', full_name='cogment.RetrieveVersionDataReplyChunk.data_chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1387,
  serialized_end=1438,
)

_MODELINFO_USERDATAENTRY.containing_type = _MODELINFO
_MODELINFO.fields_by_name['user_data'].message_type = _MODELINFO_USERDATAENTRY
_MODELVERSIONINFO_USERDATAENTRY.containing_type = _MODELVERSIONINFO
_MODELVERSIONINFO.fields_by_name['user_data'].message_type = _MODELVERSIONINFO_USERDATAENTRY
_CREATEORUPDATEMODELREQUEST.fields_by_name['model_info'].message_type = _MODELINFO
_RETRIEVEMODELSREPLY.fields_by_name['model_infos'].message_type = _MODELINFO
_CREATEVERSIONREQUESTCHUNK_HEADER.fields_by_name['version_info'].message_type = _MODELVERSIONINFO
_CREATEVERSIONREQUESTCHUNK_HEADER.containing_type = _CREATEVERSIONREQUESTCHUNK
_CREATEVERSIONREQUESTCHUNK_BODY.containing_type = _CREATEVERSIONREQUESTCHUNK
_CREATEVERSIONREQUESTCHUNK.fields_by_name['header'].message_type = _CREATEVERSIONREQUESTCHUNK_HEADER
_CREATEVERSIONREQUESTCHUNK.fields_by_name['body'].message_type = _CREATEVERSIONREQUESTCHUNK_BODY
_CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg'].fields.append(
  _CREATEVERSIONREQUESTCHUNK.fields_by_name['header'])
_CREATEVERSIONREQUESTCHUNK.fields_by_name['header'].containing_oneof = _CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg']
_CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg'].fields.append(
  _CREATEVERSIONREQUESTCHUNK.fields_by_name['body'])
_CREATEVERSIONREQUESTCHUNK.fields_by_name['body'].containing_oneof = _CREATEVERSIONREQUESTCHUNK.oneofs_by_name['msg']
_CREATEVERSIONREPLY.fields_by_name['version_info'].message_type = _MODELVERSIONINFO
_RETRIEVEVERSIONINFOSREPLY.fields_by_name['version_infos'].message_type = _MODELVERSIONINFO
DESCRIPTOR.message_types_by_name['ModelInfo'] = _MODELINFO
DESCRIPTOR.message_types_by_name['ModelVersionInfo'] = _MODELVERSIONINFO
DESCRIPTOR.message_types_by_name['CreateOrUpdateModelRequest'] = _CREATEORUPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['CreateOrUpdateModelReply'] = _CREATEORUPDATEMODELREPLY
DESCRIPTOR.message_types_by_name['RetrieveModelsRequest'] = _RETRIEVEMODELSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveModelsReply'] = _RETRIEVEMODELSREPLY
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelReply'] = _DELETEMODELREPLY
DESCRIPTOR.message_types_by_name['CreateVersionRequestChunk'] = _CREATEVERSIONREQUESTCHUNK
DESCRIPTOR.message_types_by_name['CreateVersionReply'] = _CREATEVERSIONREPLY
DESCRIPTOR.message_types_by_name['RetrieveVersionInfosRequest'] = _RETRIEVEVERSIONINFOSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveVersionInfosReply'] = _RETRIEVEVERSIONINFOSREPLY
DESCRIPTOR.message_types_by_name['RetrieveVersionDataRequest'] = _RETRIEVEVERSIONDATAREQUEST
DESCRIPTOR.message_types_by_name['RetrieveVersionDataReplyChunk'] = _RETRIEVEVERSIONDATAREPLYCHUNK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), {

  'UserDataEntry' : _reflection.GeneratedProtocolMessageType('UserDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELINFO_USERDATAENTRY,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.ModelInfo.UserDataEntry)
    })
  ,
  'DESCRIPTOR' : _MODELINFO,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ModelInfo)
  })
_sym_db.RegisterMessage(ModelInfo)
_sym_db.RegisterMessage(ModelInfo.UserDataEntry)

ModelVersionInfo = _reflection.GeneratedProtocolMessageType('ModelVersionInfo', (_message.Message,), {

  'UserDataEntry' : _reflection.GeneratedProtocolMessageType('UserDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELVERSIONINFO_USERDATAENTRY,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.ModelVersionInfo.UserDataEntry)
    })
  ,
  'DESCRIPTOR' : _MODELVERSIONINFO,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ModelVersionInfo)
  })
_sym_db.RegisterMessage(ModelVersionInfo)
_sym_db.RegisterMessage(ModelVersionInfo.UserDataEntry)

CreateOrUpdateModelRequest = _reflection.GeneratedProtocolMessageType('CreateOrUpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORUPDATEMODELREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateOrUpdateModelRequest)
  })
_sym_db.RegisterMessage(CreateOrUpdateModelRequest)

CreateOrUpdateModelReply = _reflection.GeneratedProtocolMessageType('CreateOrUpdateModelReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEORUPDATEMODELREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateOrUpdateModelReply)
  })
_sym_db.RegisterMessage(CreateOrUpdateModelReply)

RetrieveModelsRequest = _reflection.GeneratedProtocolMessageType('RetrieveModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMODELSREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveModelsRequest)
  })
_sym_db.RegisterMessage(RetrieveModelsRequest)

RetrieveModelsReply = _reflection.GeneratedProtocolMessageType('RetrieveModelsReply', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEMODELSREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveModelsReply)
  })
_sym_db.RegisterMessage(RetrieveModelsReply)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

DeleteModelReply = _reflection.GeneratedProtocolMessageType('DeleteModelReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.DeleteModelReply)
  })
_sym_db.RegisterMessage(DeleteModelReply)

CreateVersionRequestChunk = _reflection.GeneratedProtocolMessageType('CreateVersionRequestChunk', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _CREATEVERSIONREQUESTCHUNK_HEADER,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.CreateVersionRequestChunk.Header)
    })
  ,

  'Body' : _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), {
    'DESCRIPTOR' : _CREATEVERSIONREQUESTCHUNK_BODY,
    '__module__' : 'cogment.api.model_registry_pb2'
    # @@protoc_insertion_point(class_scope:cogment.CreateVersionRequestChunk.Body)
    })
  ,
  'DESCRIPTOR' : _CREATEVERSIONREQUESTCHUNK,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateVersionRequestChunk)
  })
_sym_db.RegisterMessage(CreateVersionRequestChunk)
_sym_db.RegisterMessage(CreateVersionRequestChunk.Header)
_sym_db.RegisterMessage(CreateVersionRequestChunk.Body)

CreateVersionReply = _reflection.GeneratedProtocolMessageType('CreateVersionReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVERSIONREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.CreateVersionReply)
  })
_sym_db.RegisterMessage(CreateVersionReply)

RetrieveVersionInfosRequest = _reflection.GeneratedProtocolMessageType('RetrieveVersionInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONINFOSREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionInfosRequest)
  })
_sym_db.RegisterMessage(RetrieveVersionInfosRequest)

RetrieveVersionInfosReply = _reflection.GeneratedProtocolMessageType('RetrieveVersionInfosReply', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONINFOSREPLY,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionInfosReply)
  })
_sym_db.RegisterMessage(RetrieveVersionInfosReply)

RetrieveVersionDataRequest = _reflection.GeneratedProtocolMessageType('RetrieveVersionDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONDATAREQUEST,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionDataRequest)
  })
_sym_db.RegisterMessage(RetrieveVersionDataRequest)

RetrieveVersionDataReplyChunk = _reflection.GeneratedProtocolMessageType('RetrieveVersionDataReplyChunk', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEVERSIONDATAREPLYCHUNK,
  '__module__' : 'cogment.api.model_registry_pb2'
  # @@protoc_insertion_point(class_scope:cogment.RetrieveVersionDataReplyChunk)
  })
_sym_db.RegisterMessage(RetrieveVersionDataReplyChunk)


_MODELINFO_USERDATAENTRY._options = None
_MODELVERSIONINFO_USERDATAENTRY._options = None

_MODELREGISTRYSP = _descriptor.ServiceDescriptor(
  name='ModelRegistrySP',
  full_name='cogment.ModelRegistrySP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1441,
  serialized_end=2000,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateOrUpdateModel',
    full_name='cogment.ModelRegistrySP.CreateOrUpdateModel',
    index=0,
    containing_service=None,
    input_type=_CREATEORUPDATEMODELREQUEST,
    output_type=_CREATEORUPDATEMODELREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModel',
    full_name='cogment.ModelRegistrySP.DeleteModel',
    index=1,
    containing_service=None,
    input_type=_DELETEMODELREQUEST,
    output_type=_DELETEMODELREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveModels',
    full_name='cogment.ModelRegistrySP.RetrieveModels',
    index=2,
    containing_service=None,
    input_type=_RETRIEVEMODELSREQUEST,
    output_type=_RETRIEVEMODELSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVersion',
    full_name='cogment.ModelRegistrySP.CreateVersion',
    index=3,
    containing_service=None,
    input_type=_CREATEVERSIONREQUESTCHUNK,
    output_type=_CREATEVERSIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveVersionInfos',
    full_name='cogment.ModelRegistrySP.RetrieveVersionInfos',
    index=4,
    containing_service=None,
    input_type=_RETRIEVEVERSIONINFOSREQUEST,
    output_type=_RETRIEVEVERSIONINFOSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveVersionData',
    full_name='cogment.ModelRegistrySP.RetrieveVersionData',
    index=5,
    containing_service=None,
    input_type=_RETRIEVEVERSIONDATAREQUEST,
    output_type=_RETRIEVEVERSIONDATAREPLYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELREGISTRYSP)

DESCRIPTOR.services_by_name['ModelRegistrySP'] = _MODELREGISTRYSP

# @@protoc_insertion_point(module_scope)
